package netsnmp

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Netsnmp_monad.NetsnmpSource

Parameters

module IO : IO

Signature

module ASN1_value = Netsnmp_raw_monad.ASN1_value

netsnmp provides high level access to SNMP functionality

include module type of struct include Netsnmp_types end
module Snmp_sec_auth_proto = Netsnmp_raw.Session.Snmp_sec_auth_proto
Sourcemodule Snmp_v1_2c_auth_data = Netsnmp_types.Snmp_v1_2c_auth_data
Sourcemodule Snmp_v3_auth_data = Netsnmp_types.Snmp_v3_auth_data
Sourcemodule Snmp_version_auth = Netsnmp_types.Snmp_version_auth
Sourcemodule Connection_info = Netsnmp_types.Connection_info
Sourcemodule Oid : sig ... end
Sourcemodule Connection : sig ... end
Sourceval add_mib_paths : string list -> unit IO.t

add_mib_paths adds directories to search for mibs in. Note that this will be used for all subsequent mib searches. raises Failure on error

Sourceval get_s : Connection.t -> string list -> (Oid.t * ASN1_value.t) list IO.t

get_s - get the values of a list of symbolic oids. The function handles loading mib modules referenced by the supplied oids, eg passing 'SNMPv2-MIB::sysDescr.0' ensures SNMPv2-MIB is loaded.

Sourceval get : Connection.t -> Oid.t list -> (Oid.t * ASN1_value.t) list IO.t

get - get the values of a list oids

Sourceval get_next : Connection.t -> Oid.t -> (Oid.t * ASN1_value.t) list IO.t

get_next - get the value of the next node after the supplied oid

Sourcemodule Raw : sig ... end